/* 
 * File: MainController.js
 * Container controller for the entire world
 */

/*jslint node: true, vars: true, bitwise: true */
/*global angular, document, ClassExample */
/* find out more about jslint: http://www.jslint.com/help.html */

"use strict";

// Creates the "backend" logical support for appMyExample
var myModule = angular.module("appMyExample", ["CSS450Timer", "CSS450Slider"]);

// registers the constructor for the controller
// NOTE: the constructor is only called _AFTER_ the </body> tag is encountered
//       this code does NOT run until the end of loading the HTML page
myModule.controller("MainCtrl", function ($scope) {
       // this is the model
    $scope.mMyWorld = new ClassExample('GLCanvas');

    $scope.eOpType = [
        {code: "0", name: "S"},
        {code: "1", name: "T"},
        {code: "2", name: "R"}
    ];
    $scope.mOpType = $scope.eOpType[0].code;
    $scope.mXform = $scope.mMyWorld.mRedSq.getXform();
    $scope.mX = $scope.mXform.getWidth();
    $scope.mY = $scope.mXform.getHeight();
    $scope.mMin = 1;
    $scope.mMax = 100;
    
    // suppor for growing the blue square
    $scope.mEnableGrow = true;
    $scope.growTheRed = function () {
        $scope.mMyWorld.increaseRedSize();
        $scope.mMyWorld.draw();
        $scope.objSetUI();
    };
    
    $scope.toggleGrow = function () {
        if ($scope.mEnableGrow)
            $scope.$broadcast("timer-started");
        else
            $scope.$broadcast("timer-stopped");
    };

    // Xform UI support
    $scope.uiChangeObjX = function () {
        switch ($scope.mOpType) {
        case "0":
            $scope.mXform.setWidth($scope.mX);
            break;
        case "1":
            $scope.mXform.setXPos($scope.mX);
            break;
        case "2":
            $scope.mXform.setRotationInDegree($scope.mX);
            break;
        }
        $scope.mMyWorld.draw();
    };
    
    $scope.uiChangeObjY = function () {
        switch ($scope.mOpType) {
        case "0":
            $scope.mXform.setHeight($scope.mY);
            break;
        case "1":
            $scope.mXform.setYPos($scope.mY);
            break;
        }
        $scope.mMyWorld.draw();
    };
    
    $scope.uiChangeOpType = function () {
        switch ($scope.mOpType) {
        case "0": // scale
            $scope.mX = $scope.mXform.getWidth();
            $scope.mY = $scope.mXform.getHeight();
            $scope.mMin = 1;
            $scope.mMax = 100;
            
            break;
        case "1": // translate
            $scope.mX = $scope.mXform.getXPos();
            $scope.mY = $scope.mXform.getYPos();
            
            $scope.mMin = 0;
            $scope.mMax = 800;
            break;
        
        case "2": // translate
            $scope.mX = $scope.mXform.getRotationInDegree();
            $scope.mY = 0;  // disabled because of binding for active
            
            $scope.mMin = -360;
            $scope.mMax = 360;
            break;
        }
        $scope.mMyWorld.draw();
    };
    
    $scope.objSetUI = function () {
        switch ($scope.mOpType) {
            case "0":
                $scope.mX = $scope.mXform.getWidth();
                $scope.mY = $scope.mXform.getHeight();
                break;
            case "1":
                $scope.mX = $scope.mXform.getXPos();
                $scope.mY = $scope.mXform.getYPos();
                break;
            case "2":
                $scope.mX = $scope.mXform.getRotationInDegree();
                break;
            }
    };
        
    $scope.mMyWorld.draw();
});