/*
 * File: MyGame.js 
 * This is the logic of our game. For now, this is very simple.
 */
/*jslint node: true, vars: true */
/*global gEngine: false, SimpleShader: false, Renderable: false, Camera: false, mat4: false, vec3: false, vec2: false */
/* find out more about jslint: http://www.jslint.com/help.html */

"use strict";  // Operate in Strict mode such that variables must be declared before used!

function ClassExample(htmlCanvasID) {
    // variables of the shader for drawing: one shader to be shared by two renderables
    this.mConstColorShader = null;

    // variables for the squares
    this.mBlueSq = null;        // these are the Renderable objects
    this.mRedSq = null;

    // Step A: Initialize the webGL Context
    gEngine.Core.initializeWebGL(htmlCanvasID);

    // Step B: Setup the camera
    this.mCamera = new Camera();

    // Step C: Create the shader
    this.mConstColorShader = new SimpleShader(
        "src/GLSLShaders/SimpleVS.glsl",      // Path to the VertexShader 
        "src/GLSLShaders/SimpleFS.glsl");    // Path to the simple FragmentShader
    this.mTLSq = new Renderable(this.mConstColorShader);
    this.mTLSq.setColor([0.9, 0.1, 0.1, 1]);
    
    // Step D: Create the Renderable objects:
    this.mBlueSq = new Renderable(this.mConstColorShader);
    this.mBlueSq.setColor([0.25, 0.25, 0.95, 1]);
    this.mRedSq = new Renderable(this.mConstColorShader);
    this.mRedSq.setColor([1, 0.25, 0.25, 1]);
    this.mTRSq = new Renderable(this.mConstColorShader);
    this.mTRSq.setColor([0.1, 0.9, 0.1, 1]);
    this.mBRSq = new Renderable(this.mConstColorShader);
    this.mBRSq.setColor([0.1, 0.1, 0.9, 1]);
    this.mBLSq = new Renderable(this.mConstColorShader);
    this.mBLSq.setColor([0.1, 0.1, 0.1, 1]);
    
    // intialize size and location
    // Centre Blue, slightly rotated square
    this.mBlueSq.getXform().setPosition(400, 300);
    this.mBlueSq.getXform().setRotationInRad(0.2); // In Radians
    this.mBlueSq.getXform().setSize(50, 50);

    // The corners 
    // centre red square
    this.mRedSq.getXform().setPosition(400, 300);
    this.mRedSq.getXform().setSize(30, 30);
    
    // top left
    this.mTLSq.getXform().setPosition(0, 600);
    this.mTLSq.getXform().setSize(30, 30);

    // top right
    this.mTRSq.getXform().setPosition(800, 600);
    this.mTRSq.getXform().setSize(30, 30);

    // bottom right
    this.mBRSq.getXform().setPosition(800, 0);
    this.mBRSq.getXform().setSize(30, 30);

    // bottom left
    this.mBLSq.getXform().setPosition(0, 0);
    this.mBLSq.getXform().setSize(30, 30);
}

ClassExample.prototype.draw = function () {

    // Step E: Clear the canvas
    gEngine.Core.clearCanvas([0.9, 0.9, 0.9, 1]);        // Clear the canvas

    // Step F: Starts the drawing by activating the camera
    this.mCamera.setupViewProjection();

    // Step G: Draw the blue square
    // Centre Blue, slightly rotated square
    this.mBlueSq.draw(this.mCamera);

    // Step H: Draw the center and the corner squares
    // centre red square
    this.mRedSq.draw(this.mCamera);

    // top left
    this.mTLSq.draw(this.mCamera);

    // top right
    this.mTRSq.draw(this.mCamera);

    // bottom right
    this.mBRSq.draw(this.mCamera);

    // bottom left
    this.mBLSq.draw(this.mCamera);
};